@@ -1,12 +1,15 @@
-from collections import OrderedDict
-from flask import Blueprint, g, _request_ctx_stack, current_app, request
-from werkzeug import LocalProxy
+import re
 from operator import attrgetter
 from types import FunctionType
 from functools import partial
+from collections import OrderedDict
+from werkzeug import LocalProxy
+from flask import Blueprint, g, _request_ctx_stack, current_app
+
 
 fs = LocalProxy(lambda: current_app.extensions['flarf'].filters)
 
+
 class FlarfFilter(object):
     """
     A class used to instance a filter result on application request
@@ -17,50 +20,67 @@ class FlarfFilter(object):
                                 Filters will be ordered from smallest number to
                                 largest
     :param filter_params:       A list of paramaters used by the filter on request.
-                                May be strings or functions. Strings must be
-                                attributes of request, found within (request.values,
-                                request.form, or request.files) or reference a
-                                method on the filter class that take request as
-                                an argument. Passed in functions must take request
-                                as a single argument.
-                                On filter run params are run in order of:
-                                   - if a function
-                                   - if an attribute of flask request
-                                   - if in request.values, request.form,
-                                     and request.files
-                                If not found, the param will be set on the filter
-                                as an attr of None.
+                                May be either string or function:
+                                   - a function that takes request as an argument
+                                   - a string 'request_x', indicating x is to be
+                                     returned from request, e.g. 'request_path'
+                                     to have the filter get request.path
+                                   - a string 'get_var' referencing a method on
+                                     the filter where 'var' is the variable you'd
+                                     like the filter to capture e.g. 'get_var'
+                                     will do self.get_var(request) to set self.var
+                                   - a string for a var found in request.values,
+                                     request.form, or request.files
     :param filter_on:           A list of routes to use the filter on, default
                                 is ['all'], except static routes
-    :param filter_skip:         A list routes to pass and not use filter.
-                                By default, all static routes are skipped
+    :param filter_skip:         A list routes/endpoints to pass over and not
+                                use filter. By default, all static routes are
+                                skipped
     """
     def __init__(self,
                  filter_tag,
                  filter_precedence=100,
                  filter_params=None,
-                 filter_on=['all'],
-                 filter_skip=None):
+                 filter_on=None,
+                 filter_pass=None):
         self.filter_tag = filter_tag
         self.filter_precedence = filter_precedence
         self.filter_params = self.set_params(filter_params)
-        self.filter_on = filter_on
-        self.filter_pass = ['static']
-        if filter_skip:
-            self.filter_pass.extend(filter_skip)
+        self.filter_on = self.set_filter_on(filter_on)
+        self.filter_pass = self.set_filter_pass(filter_pass)
 
     def set_params(self, params):
-        d = OrderedDict()
-        for p in params:
-            if isinstance(p, FunctionType):
-                d[p.__name__] = p
-            elif p[:4] == 'get_':
-                d[p[4:]] = partial(getattr(self, p))
-            elif hasattr(request, p):
-                d[p] = partial(getattr(self, 'param_request'), p)
-            else:
-                d[p] = partial(getattr(self, 'param_param'), p)
-        return d
+        return OrderedDict([self.param_is(p) for p in params])
+
+    def set_filter_on(self, filter_on):
+        if not filter_on:
+            filter_on = ['all']
+        return self.re_compile_list(filter_on)
+
+    def set_filter_pass(self, filter_pass):
+        if not filter_pass:
+            filter_pass = ['static']
+        else:
+            filter_pass.append('static')
+        return self.re_compile_list(filter_pass)
+
+    def re_compile_list(self, l):
+        return re.compile(r'(?:{})'.format('|'.join(l)))
+
+    def param_is(self, p):
+        if isinstance(p, FunctionType):
+            return (p.__name__, p)
+        else:
+            return self.determine_param(p)
+
+    def determine_param(self, from_p):
+        p = from_p.partition('_')
+        if p[0] == 'request':
+            return p[2], partial(getattr(self, 'param_request'), p[2])
+        elif p[0] in ('get', 'self'):
+            return p[2], partial(getattr(self, from_p))
+        else:
+            return from_p, partial(getattr(self, 'param_param'), from_p)
 
     def get_ctx_prc(self):
         def ctx_prc(tag):
@@ -87,6 +107,9 @@ class FlarfFilter(object):
         self.filter_by_param(request)
         setattr(g, self.filter_tag, self)
 
+    def no_filter(self):
+        setattr(g, self.filter_tag, None)
+
 
 class Flarf(object):
     """
@@ -99,6 +122,7 @@ class Flarf(object):
                                 FlarfFilter, used when receiving dicts as filters
     :param filters:             A list of filter instances(or dicts mappable
                                 to filter_cls instances) to be run per request.
+
     """
     def __init__(self,
                  app=None,
@@ -123,12 +147,9 @@ class Flarf(object):
             return self.flarf_run_filters
 
     def process_filters(self, filters):
-        d = OrderedDict()
         fs = self.check_filters(filters)
         ofs = self.order_filters(fs)
-        for f in ofs:
-            d[f.filter_tag] = f
-        return d
+        return OrderedDict([(f.filter_tag, f) for f in ofs])
 
     def check_filters(self, filters):
         return [self.reflect_filter(f) for f in filters]
@@ -152,15 +173,11 @@ class Flarf(object):
         app.extensions['flarf'] = self
 
     def flarf_run_filters(self):
-        """
-        A before_request function registered on the extension that runs each filter.
-        """
         r = _request_ctx_stack.top.request
-        if r.url_rule:
-            request_endpoint = str(r.endpoint).rsplit('.')[-1]
-            for f in self.filters.values():
-                if request_endpoint not in f.filter_pass:
-                    if request_endpoint or 'all' in f.filter_on:
-                        rv = f.filter_request(r)
-                        if rv:
-                            return rv
+        request_points = [str(r.endpoint).rsplit('.')[-1], r.path]
+        for f in self.filters.values():
+            if not any([f.filter_pass.match(ff) for ff in request_points]):
+                if f.filter_on.match('all') or any([f.filter_on.match(ff) for ff in request_points]):
+                    rv = f.filter_request(r)
+                    if rv:
+                        return rv
